@@ -23,6 +23,11 @@ from .connections import (
     sqlquery,
     sqlupdate,
 )
-from .databases import is_set_current_database_supported, reset_current_database, set_current_database, \
-    set_default_connection_parameters
+from .databases import (
+    is_set_current_database_supported,
+    reset_current_database,
+    set_current_database,
+    set_database_init_hook,
+    set_default_connection_parameters,
+)
 from .exceptions import DBNotPreparedError
